@@ -56,6 +56,7 @@ Ext.ux.RapidApp.Plugin.HtmlEditor.SimpleCAS_Image = Ext.extend(Ext.ux.form.HtmlE
 	
 	selectImage: function() {
 		
+    var pfx = Ext.ux.RapidApp.AJAX_URL_PREFIX || '';
 		
 		var upload_field = {
 			xtype: 'fileuploadfield',
@@ -103,11 +104,12 @@ Ext.ux.RapidApp.Plugin.HtmlEditor.SimpleCAS_Image = Ext.extend(Ext.ux.form.HtmlE
 				});
 			}
 			
-			img.link_url = '/simplecas/fetch_content/' + img.checksum + '/' + img.filename;
+			img.link_url = [pfx,'/simplecas/fetch_content/',img.checksum,'/',img.filename].join('');
 			this.insertImage(img);
 		};
 		
-		var url = '/simplecas/upload_image';
+		// Note: the pfx will be applied within Ajax code 
+    var url = '/simplecas/upload_image';
 		if(this.maxImageWidth) { url += '/' + this.maxImageWidth; }
 		
 		Ext.ux.RapidApp.WinFormPost.call(this,{
@@ -365,7 +367,7 @@ Ext.ux.RapidApp.Plugin.HtmlEditor.LoadHtmlFile = Ext.extend(Ext.util.Observable,
 			title: 'Load from File (replace existing content)',
 			width: 430,
 			height:140,
-			url:'/simplecas/texttranscode/transcode_html',
+			url:'/simplecas/texttranscode/transcode_html', // <-- Note: the pfx will be applied within Ajax code 
 			useSubmit: true,
 			fileUpload: true,
 			fieldset: fieldset,
@@ -408,10 +410,13 @@ Ext.ux.RapidApp.Plugin.HtmlEditor.SaveMhtml = Ext.extend(Ext.util.Observable, {
 	
 	downloadFile: function() {
 		var html = this.cmp.getRawValue();
+    
+    var pfx = Ext.ux.RapidApp.AJAX_URL_PREFIX || '';
+    var url = [pfx,'/simplecas/texttranscode/generate_mhtml_download'].join('');
 
 		//Ext.ux.iframeBgDownload(
-		//Ext.ux.postwith('/simplecas/texttranscode/generate_mhtml_download',{
-		Ext.ux.iFramePostwith('/simplecas/texttranscode/generate_mhtml_download',{
+		//Ext.ux.postwith(url,{
+		Ext.ux.iFramePostwith(url,{
 			html_enc: Ext.encode({ data: html })
 		});
 	}
@@ -446,12 +451,16 @@ Ext.ux.RapidApp.Plugin.HtmlEditor.LoadHelp = Ext.extend(Ext.util.Observable, {
 		}
 	},
 	
+  // TODO: This is old, not used anyplace else, and needs brought into the fold with
+  // the newer stuff like Template::Controller, etc (GitHub Issue #116)
 	showWindow: function(){
+    var pfx = Ext.ux.RapidApp.AJAX_URL_PREFIX || '';
+    var url = [pfx,'/assets/rapidapp/misc/static/html/htmleditor_load_download_help.html'].join('');
 		Ext.ux.RapidApp.showIframeWindow({
 			title: this.title,
 			height: this.height,
 			width: this.width,
-			src: '/assets/rapidapp/misc/static/html/htmleditor_load_download_help.html'
+			src: url
 		});
 	}
 	
@@ -475,13 +484,18 @@ Ext.ux.RapidApp.Plugin.HtmlEditor.InsertFile = Ext.extend(Ext.util.Observable, {
 	init: function(cmp){
 		this.cmp = cmp;
 		this.cmp.on('render', this.onRender, this);
-		
-		var getDocMarkup_orig = this.cmp.getDocMarkup;
-		this.cmp.getDocMarkup = function() {
-			return '<link rel="stylesheet" type="text/css" href="/assets/rapidapp/filelink/current/filelink.css" />' +
-				getDocMarkup_orig.apply(this,arguments);
-		}
-	},
+    
+    var pfx = Ext.ux.RapidApp.AJAX_URL_PREFIX || '';
+    var url = [pfx,'/assets/rapidapp/filelink/current/filelink.css'].join('');
+    
+    var getDocMarkup_orig = this.cmp.getDocMarkup;
+    this.cmp.getDocMarkup = function() {
+      return [
+        '<link rel="stylesheet" type="text/css" href="',url,'" />',
+        getDocMarkup_orig.apply(this,arguments)
+      ].join('');
+    }
+  },
 	
 	onRender: function() {
 		this.btn = this.cmp.getToolbar().addButton({
@@ -523,9 +537,11 @@ Ext.ux.RapidApp.Plugin.HtmlEditor.InsertFile = Ext.extend(Ext.util.Observable, {
 			items:[ upload_field ]
 		};
 		
+    var pfx = Ext.ux.RapidApp.AJAX_URL_PREFIX || '';
+    
 		var callback = function(form,res) {
 			var packet = Ext.decode(res.response.responseText);
-			var url = '/simplecas/fetch_content/' + packet.checksum + '/' + packet.filename;
+			var url = [pfx,'/simplecas/fetch_content/',packet.checksum,'/',packet.filename].join('');
 			var link = '<a class="' + packet.css_class + '" href="' + url + '">' + packet.filename + '</a>';
 			this.insertContent(link);
 		};
@@ -534,7 +550,7 @@ Ext.ux.RapidApp.Plugin.HtmlEditor.InsertFile = Ext.extend(Ext.util.Observable, {
 			title: 'Insert file',
 			width: 430,
 			height:140,
-			url:'/simplecas/upload_file',
+      url: '/simplecas/upload_file', // <-- Note: the pfx will be applied within Ajax code 
 			useSubmit: true,
 			fileUpload: true,
 			fieldset: fieldset,
